@@ -185,13 +185,6 @@
 #define DEFAULT_FIRST_LINE NULL
 #define DEFAULT_FLOATING_POINT_MATH 0
 #define DEFAULT_FLOATING_POINT_PRECISION 16
-#define DEFAULT_FLOOD_AFTER 3
-#define DEFAULT_FLOOD_IGNORE 0
-#define DEFAULT_FLOOD_MASKUSER 0
-#define DEFAULT_FLOOD_RATE 1
-#define DEFAULT_FLOOD_RATE_PER 10
-#define DEFAULT_FLOOD_USERS 3
-#define DEFAULT_FLOOD_WARNING 0
 #define DEFAULT_HIDE_PRIVATE_CHANNELS 0
 #define DEFAULT_HIGHLIGHT_CHAR "BOLD"
 #define DEFAULT_HIGH_BIT_ESCAPE 2
@@ -228,7 +221,6 @@
 #define DEFAULT_OLD_SERVER_LASTLOG_LEVEL "NONE"
 #define DEFAULT_PAD_CHAR ' '
 #define DEFAULT_QUIT_MESSAGE "ircII %s -- Are we there yet?"
-#define DEFAULT_RANDOM_SOURCE 0
 #define DEFAULT_SCREEN_OPTIONS NULL
 #define DEFAULT_SCROLLBACK 256
 #define DEFAULT_SCROLLBACK_RATIO 50
