@@ -61,8 +61,8 @@
 #define ITALIC_TOG_STR	"\020"
 #define COLOR_TAG	'\003'		/* ^C */
 #define COLOR_TAG_STR	"\003"
-#define COLOR256_TAG	'\030'		/* ^X */
-#define	COLOR256_TAG_STR "\030"
+#define COLOR_EXTENDED_TAG	'\030'		/* ^X */
+#define	COLOR_EXTENDED_TAG_STR  "\030"
 
 #define IRCD_BUFFER_SIZE	512
 /* Last two bytes are always reserved for \r\n */
@@ -88,7 +88,7 @@
 extern		int	background;
 extern		int	current_numeric;
 extern		int	dead;
-extern volatile	int	dead_children_processes;
+extern volatile	sig_atomic_t	dead_children_processes;
 extern		int	dont_connect;
 extern		int	dumb_mode;
 extern		int	foreground;
@@ -143,6 +143,7 @@ extern struct timeval	idle_time;
 extern struct timeval	now;
 extern struct timeval	input_timeout;
 extern		jmp_buf	panic_jumpseat;
+extern		intmax_t sequence_point;
 
 extern const	char *	compile_info;
 extern const 	char 	configure_args[];
@@ -150,6 +151,7 @@ extern const 	char 	compiler_version[];
 extern const	char	final_link[];
 extern const	char	compile_cflags[];
 extern const	char	compile_libs[];
+extern const	char	git_commit[];
 
 /* irc.c's extern functions */
 	void	io 			(const char *);
