@@ -17,205 +17,174 @@
 #include "network.h"
 #include "words.h"
 
+
 struct metric_time {
 	long mt_days;
 	double mt_mdays;
 };
 
-typedef int 	comp_len_func 		(char *, char *, int);
-typedef int 	comp_func 		(char *, char *);
-
-#define new_malloc(x) really_new_malloc	((x), __FILE__, __LINE__)
-#define new_free(x)   really_new_free	((void **)(x), __FILE__, __LINE__)
-#define new_realloc(x,y) really_new_realloc ((x), (y), __FILE__, __LINE__)
-#define MUST_BE_MALLOCED(x, y) \
-		fatal_malloc_check ((void *)(x), (y), __FILE__, __LINE__)
-#define RESIZE(x, y, z) new_realloc	((void **)& (x), sizeof(y) * (z))
-
-#define malloc_strcat(x,y) malloc_strcat_c((x),(y),NULL)
-#define malloc_strcat_ues(x,y,z) malloc_strcat_ues_c((x),(y),(z),NULL)
-
-extern	int	need_delayed_free;
+/**********************************************************************/
+	/* - - - - Functions dealing with malloc - - - - */
+#define new_malloc(x) 			really_new_malloc ((x), __FILE__, __LINE__)
+#define new_free(x)   			really_new_free	((void **)(x), __FILE__, __LINE__)
+#define new_realloc(x,y) 		really_new_realloc ((x), (y), __FILE__, __LINE__)
+#define MUST_BE_MALLOCED(x, y) 		fatal_malloc_check ((void *)(x), (y), __FILE__, __LINE__)
+#define RESIZE(x, y, z) 		new_realloc ((void **)& (x), sizeof(y) * (z))
 	void	fatal_malloc_check	(void *, const char *, const char *, int);
 	void *	really_new_malloc 	(size_t, const char *, int);
 	void *	really_new_free 	(void **, const char *, int);
 	void *	really_new_realloc 	(void **, size_t, const char *, int);
-	void	malloc_dump		(const char *);
 
-	char *	check_nickname 		(char *, int);
-	char *	new_new_next_arg_count 	(char *, char **, char *, int);
-	char *	last_arg 		(char **, size_t *, int);
-
-	int	normalize_filename	(const char *, Filename);
-	int	expand_twiddle 		(const char *, Filename);
-	char *	upper 			(char *);
-	char *	lower 			(char *);
-	char *	sindex			(char *, const char *);
-	char *	rsindex 		(char *, char *, char *, int);
-	const char * cpindex 		(const char *, const char *, int, size_t *);
-	ptrdiff_t cpindex2 		(const char *, const char *, int, size_t *, int *);
-	const char * rcpindex 		(const char *, const char *, const char *, int, size_t *);
-	ptrdiff_t    rcpindex2 		(const char *, const char *, const char *, int, size_t *, int *);
-
-	ssize_t	findchar_quoted		(const char *, int);
-	int	path_search 		(const char *, const char *, Filename);
-	size_t	double_quote 		(const char *, const char *, char *, size_t);
-	char *	malloc_strcat_c		(char **, const char *, size_t *);
-	void	wait_new_free 		(char **);
+	/* - - - - Functions dealing with copying strings - - - - */
 	char *	malloc_sprintf 		(char **, const char *, ...) __A(2);
 	char *	malloc_vsprintf 	(char **, const char *, va_list);
-	int	is_number 		(const char *);
-	int	is_real_number 		(const char *);
-	const char *	my_ctime 	(time_t);
-	int     rgb_to_256 		(uint8_t r, uint8_t g, uint8_t b);
-	size_t  hex256			(uint8_t x, char **retval);
+	char *	malloc_strcdup		(int, ...);
+#define		malloc_strdup(x)	malloc_strcdup(1, x)
+#define		malloc_strdup2(x,y)	malloc_strcdup(2, x, y)
+#define		malloc_strdup3(x,y,z)	malloc_strcdup(3, x, y, z)
+	char *	malloc_strext	 	(const char *, ptrdiff_t);
+	char *	malloc_strcpy		(char **, const char *);
+	char *	malloc_strcat		(char **, const char *);
+	char *	malloc_strcat_ues	(char **, const char *, const char *);
+	char *	malloc_strcat_word      (char **, const char *, const char *, int);
+	char *	malloc_strcat_wordlist  (char **, const char *, const char *);
+	char *	malloc_sprintf 		(char **, const char *, ...) __A(2);
+	char *  malloc_vsprintf		(char **, const char *, va_list);
 
+	/* - - - - Functions dealing with irc things - - - - */
+	char *	check_nickname 		(char *, int);
+	int	figure_out_address	(const char *, char **, char **, char **);
 
-	int	my_table_strnicmp 	(const char *, const char *, size_t, int);
-#define my_table_stricmp(x, y, t) my_table_strnicmp(x, y, UINT_MAX, t)
-	int	server_strnicmp		(const char *, const char *, size_t, int);
-#define server_stricmp(x, y, s)	server_strnicmp(x, y, UINT_MAX, s)
-	int	my_strnicmp 		(const char *, const char *, size_t);
-	int	my_stricmp 		(const char *, const char *);
-	int     my_strncmp 		(const char *, const char *, size_t);
-	int	ascii_strnicmp 		(const char *, const char *, size_t);
-	int	ascii_stricmp 		(const char *, const char *);
-	int	rfc1459_strnicmp 	(const char *, const char *, size_t);
-	int	rfc1459_stricmp 	(const char *, const char *);
-	int     alist_stricmp 		(const char *, const char *, size_t);
+	/* - - - - Functions dealing with ircII syntax - - - - */
+	ssize_t	MatchingBracket 	(const char *, char, char);
+	char *	remove_brackets 	(const char *, const char *);
+	char *	next_in_comma_list	(char *, char **);
+	char *	next_in_div_list	(char *, char **, int);
+	int	remove_from_comma_list	(char *str, const char *what);
+	size_t	escape_chars 		(const char *, const char *, char *, size_t);
 
-	char *  uuid4_generate 		(void);
-	char *	uuid4_generate_no_dashes	(void);
-
-	void	really_free 		(int);
-	char *	chop 			(char *, size_t);
-	char *	malloc_strcat_ues_c	(char **, const char *, const char *, size_t *);
-	char *	strlopencat		(char *, size_t, ...);
-	ssize_t	stristr 		(const char *, const char *);
-	ssize_t	rstristr 		(const char *, const char *);
-struct 	epic_loadfile *	uzfopen 	(char **, const char *, int, struct stat *);
-	int	end_strcmp 		(const char *, const char *, size_t);
-	char*   exec_pipe		(const char *, char *, size_t *, char *const *);
-	FILE **	open_exec		(const char *executable, char * const *args);
-	void	panic 			(int, const char *, ...) __A(2) __N;
-	int	fw_strcmp 		(comp_len_func *, char *, char *);
-	int	lw_strcmp 		(comp_func *, char *, char *);
-	int	open_to 		(char *, int, int);
-struct 	metric_time get_metric_time	(double *);
-struct 	metric_time timeval_to_metric	(const Timeval *);
-	Timeval get_time		(Timeval *);
-	double 	time_diff 		(const Timeval, const Timeval);
-	Timeval time_add		(const Timeval, const Timeval);
-	Timeval time_subtract		(const Timeval, const Timeval);
-	Timeval double_to_timeval 	(double);
-	double  time_since_startup 	(Timeval t);
-const 	char *	plural 			(int);
-	double	time_to_next_minute 	(void);
-	char *	remove_trailing_spaces 	(char *, size_t *cluep);
-	char *	forcibly_remove_trailing_spaces (char *, size_t *);
-#define ltoa my_ltoa
-const 	char *	my_ltoa 		(long);
-const 	char *	intmaxtoa 		(intmax_t);
-const 	char *	ftoa			(double);
-
-	char *	chop_word 		(char *);
-	char *	skip_spaces		(char *);
+	/* - - - - Functions dealing with words - - - - */
+	char *  universal_next_arg_count (char *, char **, int, int, int, const char *);
+	char *	new_new_next_arg_count 	(char *, char **, char *, int);
+	char *	last_arg 		(char **, int);
 	int	split_args		(char *, char **to, size_t);
-	int	splitw 			(char *, char ***, int);
+	int	split_wordlist 		(char *, char ***, int);
 	char *	unsplitw 		(char ***, int, int);
 	int	new_split_string 	(char *, char ***, int);
-	int	split_string 		(char *, char ***, char);
-	int	check_val 		(const char *);
-	char *	strext	 		(const char *, const char *);
-	char *	strextend 		(char *, char, int);
-	char *	pullstr 		(char *, char *);
-	int 	empty 			(const char *);
-	char *	safe_new_next_arg	(char *, char **);
-	char *	safe_next_arg		(char *, char **);
-	ssize_t	MatchingBracket 	(const char *, char, char);
-	int	parse_number 		(char **);
-	char *	remove_brackets 	(const char *, const char *);
-	long	my_atol 		(const char *);
-	char *	malloc_dupchar 		(int);
+
+	/* - - - - Functions dealing with Filenames - - - - */
+	int	normalize_filename	(const char *, Filename);
+	int	expand_twiddle 		(const char *, Filename);
+	int	path_search 		(const char *, const char *, Filename);
+struct 	epic_loadfile *	uzfopen 	(char **, const char *, int, struct stat *);
 	off_t	file_size		(const char *);
 	int	file_exists		(const char *);
 	int	isdir			(const char *);
 	int	isdir2			(const char *, const void * const);
-	int	is_root			(const char *, const char *, int);
+
+	/* - - - - - - */
+#define my_isspace(x) isspace(x)
+#define my_isdigit(x) (isdigit(*x) || ((*x == '-' || *x == '+') && isdigit(x[1])))
+
+	/* - - - - Functions dealing with characters in strings - - - - */
+	const char * 	cpindex 	(const char *, const char *, int, size_t *);
+	ptrdiff_t 	cpindex2 	(const char *, const char *, int, size_t *, int *);
+	const char * 	rcpindex 	(const char *, const char *, const char *, int, size_t *);
+	ptrdiff_t    	rcpindex2 	(const char *, const char *, const char *, int, size_t *, int *);
+	ssize_t		findchar_honor_escapes (const char *, int);
+	int		charcount	(const char *, char);
+	int     	check_xdigit 	(char digit);
+
+	/* - - - - Functions dealing with comparing strings - - - - */
+	int	my_table_strnicmp 	(const char *, const char *, size_t, int);
+#define my_table_stricmp(x, y, t) my_table_strnicmp(x, y, UINT_MAX, t)
+	int	server_strnicmp		(const char *, const char *, size_t, int);
+#define server_stricmp(x, y, s)	server_strnicmp(x, y, UINT_MAX, s)
+	int	my_stricmp 		(const char *, const char *);
+	int     my_strncmp 		(const char *, const char *, size_t);
+	int	my_strnicmp 		(const char *, const char *, size_t);
+	int	ascii_stricmp 		(const char *, const char *);
+	int	ascii_strnicmp 		(const char *, const char *, size_t);
+	int	rfc1459_stricmp 	(const char *, const char *);
+	int	rfc1459_strnicmp 	(const char *, const char *, size_t);
+	int     alist_stricmp 		(const char *, const char *, size_t);
+	int	vmy_strnicmp		(size_t, char *, ...);
+	int	end_strcmp 		(const char *, const char *, size_t);
+
+	ssize_t	stristr 		(const char *, const char *);
+	ssize_t	rstristr 		(const char *, const char *);
 	size_t	streq			(const char *, const char *);
-	char *	malloc_strndup		(const char *, size_t);
-	char *	prntdump		(const char *, size_t);
-	char *	ov_strcpy		(char *, const char *);
-	size_t	ccspan			(const char *, int);
-	int	last_char		(const char *);
-	char *	next_in_comma_list	(char *, char **);
-	char *	next_in_div_list	(char *, char **, int);
-	char *	get_userhost		(void);
-	double  time_to_next_interval	(int interval);
-	int	charcount		(const char *, char);
-	void	beep_em			(int);
-	void	strip_control		(const char *, char *);
-const 	char *	strfill			(char, int);
+
+	/* - - - - Functions dealing with spaces and emptiness - - - - */
+	int 	empty 			(const char *);
+	int     is_string_empty 	(const char *str);
+	char *	skip_spaces		(char *);
+	char *	remove_trailing_spaces 	(char *, int);
+	char *	endstr			(char *);
+const 	char *	nonull			(const char *);
+
+	/* - - - - Functions dealing with mutating strings in place - - - - */
+	char *	upper 			(char *);
+	char *	lower 			(char *);
+	void    dequoter                (char **, int, int, const char *);
+	char *	chop 			(char *, size_t);
 	char *	chomp			(char *);
-	int 	opento			(const char *, int, off_t);
-	int	figure_out_address	(const char *, char **, char **, char **);
-	int	figure_out_domain	(char *, char **, char **, int *);
-	int	count_char		(const char *, const char);
-	char *	strnrchr		(char *, char, int);
-	void	mask_digits		(char **);
+
+	/* - - - - Functions dealing with copying or extracting strings in place - - - - */
+	char *	strlopencpy		(char *, size_t, ...);
+	int	strext2			(char **, char *, size_t , size_t);
+	char *	strextend 		(char *, char, int);
 	char *	strpcat			(char *, const char *, ...) __A(2);
 	char *  strlpcat		(char *, size_t, const char *, ...) __A(3);
+	char *	pullstr 		(char *, char *);
+	char *	ov_strcpy		(char *, const char *);
+
+	/* - - - - (High level) Functions dealing with copying or extracting strings in place - - - - */
+	char *	fix_string_width	(const char *, int, int, size_t, int);
+	char *	substitute_string	(const char *, const char *, const char *, int, int);
+
+	/* - - - - Functions dealing with numbers - - - - */
+#define ltoa intmaxtoa
+	int	is_number 		(const char *);
+	int	is_real_number 		(const char *);
+const 	char *	intmaxtoa 		(intmax_t);
+const 	char *	ftoa			(double);
+	int	check_val 		(const char *);
+	int	parse_number 		(char **);
+	long	my_atol 		(const char *);
+
+	/* - - - - Functions dealing with time - - - - */
+	const char *	my_ctime 		(time_t);
+struct 	metric_time 	get_metric_time		(double *);
+struct 	metric_time 	timeval_to_metric	(const Timeval *);
+	Timeval 	get_time		(Timeval *);
+	double 		time_diff 		(const Timeval, const Timeval);
+	Timeval 	time_add		(const Timeval, const Timeval);
+	Timeval 	time_subtract		(const Timeval, const Timeval);
+	Timeval 	double_to_timeval 	(double);
+	double  	time_to_next_interval	(int interval);
+
+	/* - - - - - - */
+	int     rgb_to_256 		(uint8_t r, uint8_t g, uint8_t b);
+	size_t  hex256			(uint8_t x, char **retval);
+
+	/* - - - - - - */
+	char *  uuid4_generate 		(void);
+	char *	uuid4_generate_no_dashes	(void);
 	unsigned long	random_number	(unsigned long);
 
-	char *	endstr			(char *);
-	ssize_t searchbuf		(const char *, size_t, size_t, int);
-	int	remove_from_comma_list	(char *str, const char *what);
-	char *	dequote_buffer		(char *str, size_t *len);
-	char *	fix_string_width	(const char *, int, int, size_t, int);
-	int     check_xdigit 		(char digit);
+	/* - - - - - - */
+	char *  exec_pipe 		(const char *executable, char *input, size_t *len, char * const *args);
+	FILE **	open_exec		(const char *executable, char * const *args);
+	void	panic 			(int, const char *, ...) __A(2) __N;
 
+	/* - - - - - - */
 	void	add_mode_to_str		(char *, size_t, int);
 	void	remove_mode_from_str	(char *, size_t, int);
 	void	clear_modes		(char *);
 	void	update_mode_str		(char *, size_t, const char *);
 
-	void	add_mode_to_str		(char *, size_t, int);
-	void	remove_mode_from_str	(char *, size_t, int);
-	void	clear_modes		(char *);
-	void	update_mode_str		(char *, size_t, const char *);
-
-	size_t	strlcpy_c		(char *, const char *, size_t, size_t *);
-	size_t	strlcat_c		(char *, const char *, size_t, size_t *);
-	char *  strlopencat_c		(char *dest, size_t maxlen, size_t *cluep, ...);
-	int     is_string_empty 	(const char *str);
-
-	char *	malloc_strcpy_c		(char **, const char *, size_t *);
-	char *	malloc_strcat_c		(char **, const char *, size_t *);
-	char *	malloc_strdup 		(const char *);
-	char *	malloc_strdup2 		(const char *, const char *);
-	char *	malloc_strdup3 		(const char *, const char *, const char *);
-	char *	malloc_strcat2_c	(char **, const char *, const char *, size_t *);
-	char *	malloc_strcat3_c	(char **, const char *, const char *, const char *, size_t *);
-	char *	malloc_strcat_wordlist_c (char **, const char *, const char *,size_t *);
-	char *	malloc_strcat_word_c    (char **, const char *, const char *, int, size_t *);
-	char *	malloc_sprintf 		(char **, const char *, ...) __A(2);
-	char *  malloc_vsprintf		(char **ptr, const char *format, va_list args);
-
-#define malloc_strcpy(x,y) malloc_strcpy_c((x),(y),NULL)
-#define malloc_strcat(x,y) malloc_strcat_c((x),(y),NULL)
-#define malloc_strcat2(x,y,z) malloc_strcat2_c((x),(y),(z),NULL)
-#define malloc_strcat_wordlist(x,y,z) malloc_strcat_wordlist_c((x),(y),(z),NULL)
-#define malloc_strcat_word(x,y,z,a) malloc_strcat_word_c((x),(y),(z),(a),NULL)
-
-	char *  universal_next_arg_count (char *, char **, int, int, int, const char *);
-	void    dequoter                (char **, size_t *, int, int, const char *);
-
-#define my_isspace(x) isspace(x)
-#define my_isdigit(x) \
-	(isdigit(*x) || ((*x == '-' || *x == '+') && isdigit(x[1])))
-
-	int	vmy_strnicmp		(size_t, char *, ...);
-	char *	substitute_string	(const char *, const char *, const char *, int, int);
+/**********************************************************************/
 
 /* ---------------- */
 /* Used for the inbound mangling stuff */
@@ -266,7 +235,7 @@ typedef struct Bucket Bucket;
 #define STRNUM(x) (strtoimax(x, NULL, 10))
 #define NUMSTR(x) (intmaxtoa((intmax_t)(x)))
 
-/********************/
+/* ---------------- */
 	void	init_transforms 	(void);
 	size_t	transform_string 	(int, int, const char *, const char *, size_t, char *, size_t);
 	int	lookup_transform 	(const char *, int *, int *, int *);
@@ -283,8 +252,7 @@ extern	int	SHA256_xform;
 #define XFORM_ENCODE 1
 #define XFORM_DECODE 0
 
-extern int 	num_code_points (const char *);
-
+/* ---------------- */
 #ifdef HAVE_ICONV
 extern struct Iconv_stuff {
 	char *stuff;
@@ -294,11 +262,14 @@ extern struct Iconv_stuff {
 extern ssize_t 	iconv_list_size;
 	int 	my_iconv_open 		(iconv_t *, iconv_t *, const char *);
 #endif
-
 	int	recode_with_iconv 	(const char *, const char *, char **, size_t *);
 	int     recode_with_iconv_t 	(iconv_t, char **, size_t *);
+	int     invalid_utf8str 	(char *);
+	int     is_iso2022_jp 		(const char *);
+	char *  cp437_to_utf8 	(const char *, size_t, size_t *);
+	int 	num_code_points (const char *);
 
-/***********************/
+/******* wcwidth.c ******/
 	int	codepoint_numcolumns 	(int);
 	int	next_code_point2 	(const char *, ptrdiff_t *, int);
 	int	partial_code_point	(const char *);
@@ -311,14 +282,6 @@ extern ssize_t 	iconv_list_size;
 	int	quick_code_point_index	(const char *, const char *);
 	int     count_initial_codepoints (const char *, const char *);
 
-	int	strext2			(char **, char *, size_t , size_t);
-	int     invalid_utf8str 	(char *);
-	int     is_iso2022_jp 		(const char *);
-	void    create_utf8_locale 	(void);
-	int	mkupper_l		(int);
-	int	mklower_l		(int);
-	char *  cp437_to_utf8 	(const char *, size_t, size_t *);
-
 /******* recode.c ******/
 	void	init_recodings		(void);
 const 	char *	find_recoding		(const char *, iconv_t *, iconv_t *);
@@ -328,6 +291,9 @@ const 	char *	find_recoding		(const char *, iconv_t *, iconv_t *);
 const 	char *	outbound_recode 	(const char *, int, const char *, char **);
 const 	char *	inbound_recode 		(const char *, int, const char *, const char *, char **);
 	char *	function_encodingctl 	(char *);
+	void    create_utf8_locale 	(void);
+	int	mkupper_l		(int);
+	int	mklower_l		(int);
 
 #endif /* _IRCAUX_H_ */
 
