@@ -47,7 +47,7 @@
 	int	get_channel_oper	(Char *, int);
 	int	get_channel_voice	(Char *, int);
 	int     get_channel_halfop	(Char *, int);
-	int	get_channel_winref	(Char *, int);
+	int	get_channel_window	(Char *, int);
 	void	set_channel_window	(Char *, int, int, int);
 	void	move_channel_to_window	(Char *, int, int, int);
 	void	reassign_window_channels (int);
@@ -56,8 +56,8 @@
 	int	auto_rejoin_callback	(void *);
 	void	channel_server_delete	(int);
 	void	channel_check_windows	(void);
-	void    channels_swap_winrefs 	(int oldref, int newref);
-	void    channels_merge_winrefs 	(int oldref, int newref);
-	int     window_claims_channel 	(int winref, int winserv, Char *channel);
+	void    channels_swap_windows 	(int oldref, int newref);
+	void    channels_merge_windows 	(int oldref, int newref);
+	int     window_claims_channel 	(int window, int winserv, Char *channel);
 
 #endif /* _NAMES_H_ */
