@@ -13,7 +13,7 @@
 /* To get declaration of "output_screen" */
 #include "screen.h"
 
-extern	volatile int	need_redraw;
+extern	volatile sig_atomic_t	need_redraw;
 extern	int	meta_mode;
 
 /* 
@@ -23,7 +23,7 @@ extern	int	meta_mode;
  * escape sequences.
  */
 #if !defined(WTERM_C) && !defined(WSERV_C)
-#define current_ftarget (output_screen ? output_screen->fpout : stdout)
+#define current_ftarget (output_screen >= 0 && get_screen_fpout(output_screen) ? get_screen_fpout(output_screen) : stdout)
 
 # ifdef __need_putchar_x__
 __inline__ static int putchar_x (int c) { 
