@@ -54,13 +54,6 @@ int	ACCEPT_INVALID_SSL_CERT_VAR,
 	FIRST_LINE_VAR,
 	FLOATING_POINT_MATH_VAR,
 	FLOATING_POINT_PRECISION_VAR,
-	FLOOD_AFTER_VAR,
-	FLOOD_IGNORE_VAR,
-	FLOOD_MASKUSER_VAR,
-	FLOOD_RATE_VAR,
-	FLOOD_RATE_PER_VAR,
-	FLOOD_USERS_VAR,
-	FLOOD_WARNING_VAR,
 	HIDE_PRIVATE_CHANNELS_VAR,
 	HIGHLIGHT_CHAR_VAR,
 	HOLD_SLIDER_VAR,
@@ -101,7 +94,6 @@ int	ACCEPT_INVALID_SSL_CERT_VAR,
 	OUTPUT_REWRITE_VAR,
 	PAD_CHAR_VAR,
 	QUIT_MESSAGE_VAR,
-	RANDOM_SOURCE_VAR,
 	SCREEN_OPTIONS_VAR,
 	SCROLLBACK_VAR,
 	SCROLLBACK_RATIO_VAR,
