@@ -149,8 +149,6 @@ typedef struct TOKEN_type
 	short	boolean_value;		/* Cached boolean value */
 } SYMBOL;
 
-#define __inline 
-
 /*
  * This is an expression context
  */
@@ -231,11 +229,11 @@ typedef struct
 #define TOK(c, v) 	c->tokens[v]
 
 /* Forward function references */
-__inline static	TOKEN	tokenize_raw (expr_info *c, const char *t);
+	static	TOKEN	tokenize_raw (expr_info *c, const char *t);
 	static	char *	after_expando_special (expr_info *c);
 	static	char *	alias_special_char (char **buffer, char *ptr, 
 					const char *args, char *quote_em);
-__inline static	const char *	get_token_expanded (expr_info *c, TOKEN v);
+	static	const char *	get_token_expanded (expr_info *c, TOKEN v);
 
 
 /******************** EXPRESSION CONSTRUCTOR AND DESTRUCTOR ****************/
@@ -458,7 +456,7 @@ static 	int 	assoc[TOKCOUNT] =
 
 /* ********************* CREATE NEW SYMBOLS AND TOKENS ********************/
 /* Lvalues are stored via this routine */
-__inline static	TOKEN		tokenize_lval (expr_info *c, const char *t)
+static	TOKEN		tokenize_lval (expr_info *c, const char *t)
 {
 	if (c->token >= TOKENCOUNT)
 	{
@@ -479,7 +477,7 @@ __inline static	TOKEN		tokenize_lval (expr_info *c, const char *t)
  * result of operators) directly create "expanded" tokens.
  */
 /* THIS FUNCTION MAKES A NEW COPY OF 'T'.  YOU MUST DISPOSE OF 'T' YOURSELF */
-__inline static	TOKEN		tokenize_raw (expr_info *c, const char *t)
+static	TOKEN		tokenize_raw (expr_info *c, const char *t)
 {
 	if (c->token >= TOKENCOUNT)
 	{
@@ -497,7 +495,7 @@ __inline static	TOKEN		tokenize_raw (expr_info *c, const char *t)
  * 'expanded' tokens never can be passed through expand_alias() again.  This
  * protects against possible security holes in the client.
  */
-__inline static	TOKEN		tokenize_expanded (expr_info *c, char *t)
+static	TOKEN		tokenize_expanded (expr_info *c, char *t)
 {
 	if (c->token >= TOKENCOUNT)
 	{
@@ -515,7 +513,7 @@ __inline static	TOKEN		tokenize_expanded (expr_info *c, char *t)
  * is both expensive, and unnecesary.  This type of token is created by
  * integer-only operations like &, |, ^, <<, >>.
  */
-__inline static	TOKEN		tokenize_integer (expr_info *c, intmax_t t)
+static	TOKEN		tokenize_integer (expr_info *c, intmax_t t)
 {
 	if (c->token >= TOKENCOUNT)
 	{
@@ -532,7 +530,7 @@ __inline static	TOKEN		tokenize_integer (expr_info *c, intmax_t t)
  * that integer tokens are, and this is the token generated by floating 
  * point operations, such as +, -, *, /, %, **.
  */
-__inline static	TOKEN		tokenize_float (expr_info *c, double t)
+static	TOKEN		tokenize_float (expr_info *c, double t)
 {
 	if (c->token >= TOKENCOUNT)
 	{
@@ -549,7 +547,7 @@ __inline static	TOKEN		tokenize_float (expr_info *c, double t)
  * integer tokens are.  This token is generated by any sort of logic 
  * operation, such as ==, !=, >, <, &&, ||.
  */
-__inline static	TOKEN		tokenize_bool (expr_info *c, BooL t)
+static	TOKEN		tokenize_bool (expr_info *c, BooL t)
 {
 	if (c->token >= TOKENCOUNT)
 	{
@@ -589,7 +587,7 @@ __inline static	TOKEN		tokenize_bool (expr_info *c, BooL t)
  * the most information, starting with expanded string, to the boolean
  * value. 
  */ 
-__inline static	const char *	get_token_raw (expr_info *c, TOKEN v)
+static	const char *	get_token_raw (expr_info *c, TOKEN v)
 {
 	if (v == MAGIC_TOKEN)	/* Magic token */
 		return c->args;			/* XXX Probably wrong */
@@ -653,7 +651,7 @@ __inline static	const char *	get_token_raw (expr_info *c, TOKEN v)
  * and only if (TOK(c, v).used & USED_LVAL)!  Otherwise, this returns
  * NULL and emits an error.
  */
-__inline static const char *	get_token_lval (expr_info *c, TOKEN v)
+static const char *	get_token_lval (expr_info *c, TOKEN v)
 {
 	if (v == MAGIC_TOKEN)	/* Magic token */
 		return c->args;			/* XXX Probably wrong */
@@ -684,7 +682,7 @@ __inline static const char *	get_token_lval (expr_info *c, TOKEN v)
  * call expand_alias() to get the value.  Of course, there is always a
  * "raw" value, as get_token_raw() can convert from anything.
  */
-__inline static	const char *	get_token_expanded (expr_info *c, TOKEN v)
+static	const char *	get_token_expanded (expr_info *c, TOKEN v)
 {
 	if (v == MAGIC_TOKEN)	/* Magic token */
 		return c->args;
@@ -724,8 +722,7 @@ __inline static	const char *	get_token_expanded (expr_info *c, TOKEN v)
 				yell(">>> Looking up variable [%d]: [%s]", 
 					v, myval);
 
-			alias_special_char(&buffer, myval, c->args, 
-					NULL);
+			alias_special_char(&buffer, myval, c->args, NULL);
 			if (!buffer)
 				buffer = malloc_strdup(empty_string);
 			TOK(c, v).expanded_value = buffer;
@@ -767,7 +764,7 @@ __inline static	const char *	get_token_expanded (expr_info *c, TOKEN v)
  * be made upon any rvalue (ick), and CrazyEddy asked me nicely to implement
  * this backwards compatability, and how could I ever say no to him? :-D
  */
-__inline static const char *	get_token_fname (expr_info *c, TOKEN v)
+static const char *	get_token_fname (expr_info *c, TOKEN v)
 {
 	if (v == MAGIC_TOKEN)	/* Magic token */
 		return c->args;			/* XXX Probably wrong */
@@ -793,7 +790,7 @@ __inline static const char *	get_token_fname (expr_info *c, TOKEN v)
  * this function, it calls atof() on the "raw" value, if there is one, 
  * to get the result.
  */
-__inline static	intmax_t	get_token_integer (expr_info *c, TOKEN v)
+static	intmax_t	get_token_integer (expr_info *c, TOKEN v)
 {
 	if (v == MAGIC_TOKEN)	/* Magic token */
 		return STR2INT(c->args);		/* XXX Probably wrong */
@@ -817,7 +814,7 @@ __inline static	intmax_t	get_token_integer (expr_info *c, TOKEN v)
 /*
  * Get the floating point value representation of the token.
  */
-__inline static	double	get_token_float (expr_info *c, TOKEN v)
+static	double	get_token_float (expr_info *c, TOKEN v)
 {
 	if (v == MAGIC_TOKEN)	/* Magic token */
 		return atof(c->args);		/* XXX Probably wrong */
@@ -841,7 +838,7 @@ __inline static	double	get_token_float (expr_info *c, TOKEN v)
 /*
  * Get the boolean value of the token
  */
-__inline static	BooL	get_token_boolean (expr_info *c, TOKEN v)
+static	BooL	get_token_boolean (expr_info *c, TOKEN v)
 {
 	if (v == MAGIC_TOKEN)	/* Magic token */
 		return check_val(c->args);	/* XXX Probably wrong */
@@ -870,7 +867,7 @@ __inline static	BooL	get_token_boolean (expr_info *c, TOKEN v)
  * when you want to shift a value that has not been tokenized.  So you call
  * one of the other functions that will do this for you.
  */
-__inline static	TOKEN	push_token (expr_info *c, TOKEN t)
+static	TOKEN	push_token (expr_info *c, TOKEN t)
 {
 	if (c->sp == STACKSZ - 1)
 	{
@@ -887,34 +884,34 @@ __inline static	TOKEN	push_token (expr_info *c, TOKEN t)
 	return ((c->stack[c->sp] = t));
 }
 
-__inline static	TOKEN	push_string (expr_info *c, char *val)
+static	TOKEN	push_string (expr_info *c, char *val)
 {
 	return push_token(c, tokenize_expanded(c, val));
 }
 
-__inline static	TOKEN	push_float (expr_info *c, double val)
+static	TOKEN	push_float (expr_info *c, double val)
 { 
 	return push_token(c, tokenize_float(c, val));
 }
 
-__inline static	TOKEN	push_integer (expr_info *c, intmax_t val)
+static	TOKEN	push_integer (expr_info *c, intmax_t val)
 { 
 	return push_token(c, tokenize_integer(c, val));
 }
 
-__inline static TOKEN	push_boolean (expr_info *c, BooL val)
+static TOKEN	push_boolean (expr_info *c, BooL val)
 {
 	return push_token(c, tokenize_bool(c, val));
 }
 
-__inline static TOKEN	push_lval (expr_info *c, const char *val)
+static TOKEN	push_lval (expr_info *c, const char *val)
 {
 	return push_token(c, tokenize_lval(c, val));
 }
 
 
 /*********************** REMOVE FROM OPERAND STACK **************************/
-__inline static TOKEN	top (expr_info *c)
+static TOKEN	top (expr_info *c)
 {
 	if (c->sp < 0)
 	{
@@ -925,7 +922,7 @@ __inline static TOKEN	top (expr_info *c)
 		return c->stack[c->sp];
 }
 
-__inline static	TOKEN	pop_token (expr_info *c)
+static	TOKEN	pop_token (expr_info *c)
 {
 	if (c->sp < 0)
 	{
@@ -941,57 +938,57 @@ __inline static	TOKEN	pop_token (expr_info *c)
 		return c->stack[c->sp--];
 }
 
-__inline static	intmax_t		pop_integer (expr_info *c)
+static	intmax_t		pop_integer (expr_info *c)
 {
 	return get_token_integer(c, pop_token(c));
 }
 
-__inline static	double		pop_float (expr_info *c)
+static	double		pop_float (expr_info *c)
 {
 	return get_token_float(c, pop_token(c));
 }
 
-__inline static	const char *	pop_expanded (expr_info *c)
+static	const char *	pop_expanded (expr_info *c)
 {
 	return get_token_expanded(c, pop_token(c));
 }
 
-__inline static	BooL		pop_boolean (expr_info *c)
+static	BooL		pop_boolean (expr_info *c)
 {
 	return get_token_boolean(c, pop_token(c));
 }
 
-__inline static void	pop_2_tokens (expr_info *c, TOKEN *t1, TOKEN *t2)
+static void	pop_2_tokens (expr_info *c, TOKEN *t1, TOKEN *t2)
 {
 	*t2 = pop_token(c);
 	*t1 = pop_token(c);
 }
 
-__inline static	void	pop_2_floats (expr_info *c, double *a, double *b)
+static	void	pop_2_floats (expr_info *c, double *a, double *b)
 {
 	*b = pop_float(c);
 	*a = pop_float(c);
 }
 
-__inline static	void	pop_2_integers (expr_info *c, intmax_t *a, intmax_t *b)
+static	void	pop_2_integers (expr_info *c, intmax_t *a, intmax_t *b)
 {
 	*b = pop_integer(c);
 	*a = pop_integer(c);
 }
 
-__inline static void	pop_2_strings (expr_info *c, const char **s, const char **t)
+static void	pop_2_strings (expr_info *c, const char **s, const char **t)
 {
 	*t = pop_expanded(c);
 	*s = pop_expanded(c);
 }
 
-__inline static void	pop_2_booleans (expr_info *c, BooL *a, BooL *b)
+static void	pop_2_booleans (expr_info *c, BooL *a, BooL *b)
 {
 	*b = pop_boolean(c);
 	*a = pop_boolean(c);
 }
 
-__inline static	void	pop_3_tokens (expr_info *c, BooL *a, TOKEN *v, TOKEN *w)
+static	void	pop_3_tokens (expr_info *c, BooL *a, TOKEN *v, TOKEN *w)
 {
 	TOKEN	t1, t2, t3;
 
@@ -1703,7 +1700,7 @@ static int	lexerr (expr_info *c, const char *format, ...)
  * case 'operand' is set to 1.  When an operand is lexed, then the next token
  * is expected to be a binary operator, so 'operand' is set to 0. 
  */
-static __inline int	check_implied_arg (expr_info *c)
+static int	check_implied_arg (expr_info *c)
 {
 	if (c->operand == 2)
 	{
@@ -1715,7 +1712,7 @@ static __inline int	check_implied_arg (expr_info *c)
 	return c->operand;
 }
 
-static __inline TOKEN 	operator (expr_info *c, const char *x, int y, TOKEN z)
+static TOKEN 	operator (expr_info *c, const char *x, int y, TOKEN z)
 {
 	check_implied_arg(c);
 	if (c->operand)
@@ -1726,7 +1723,7 @@ static __inline TOKEN 	operator (expr_info *c, const char *x, int y, TOKEN z)
 	return z;
 }
 
-static __inline TOKEN 	unary (expr_info *c, const char *x, int y, TOKEN z)
+static TOKEN 	unary (expr_info *c, const char *x, int y, TOKEN z)
 {
 	if (!c->operand)
 		return lexerr(c, "A unary operator (%s) was found where "
@@ -2401,7 +2398,6 @@ static void	mathparse (expr_info *c, int pc)
 		{
 			const char *funcname, *args;
 			char *hack = NULL;
-			size_t clue = 0;
 			char *retval;
 			int	func_token;
 
@@ -2413,17 +2409,13 @@ static void	mathparse (expr_info *c, int pc)
 				push_token(c, 0);
 			else
 			{
-			    malloc_strcpy_c(&hack, funcname, &clue);
-			    malloc_strcat_c(&hack, "(", &clue);
-			    malloc_strcat_c(&hack, args, &clue);
-			    malloc_strcat_c(&hack, ")", &clue);
+			    malloc_sprintf(&hack, "%s(%s)", funcname, args);
 
 			    if (x_debug & DEBUG_NEW_MATH_DEBUG)
 				yell("Parsed function call %s", hack);
 
 			    retval = call_function(hack, c->args);
 			    c->last_token = tokenize_expanded(c, retval);
-
 			    push_token(c, c->last_token);
 			}
 			break;
