@@ -51,8 +51,7 @@
  * PASSING NULL TO parse_line() or parse_arglist() OR SIMILAR FUNCTIONS
  * WILL RETURN IN A PANIC.  DO NOT IGNORE THIS!
  */
-static __inline__
-char *	my_next_expr (char **args, char type, int whine, int wantchar)
+static char *	my_next_expr (char **args, char type, int whine, int wantchar)
 {
 	char	*expr_start,
 		*expr_end;
@@ -90,7 +89,7 @@ char *	my_next_expr (char **args, char type, int whine, int wantchar)
 
 	/* Remove any extraneous whitespace in the expression */
 	expr_start = skip_spaces(expr_start + 1);
-	remove_trailing_spaces(expr_start, 0);
+	remove_trailing_spaces(expr_start, 1);
 
 	/*
 	 * It is guaranteed that (ptr2[-1] >= *args) and so it is further
@@ -476,7 +475,6 @@ BUILT_IN_COMMAND(fe)
 	char	*mapvar = NULL;
 	const char	*mapsep = doing_fe ? space : empty_string;
 	char	*map = NULL;
-	size_t	mapclue = 0;
 
 	if (!subargs)
 		subargs = empty_string;
@@ -568,11 +566,14 @@ BUILT_IN_COMMAND(fe)
 		runcmds(todo, subargs);
 
 		if (mapvar)
-			for ( y = 0 ; y < ind ; y++ ) {
-				char *foo = get_variable(var[y]);
-				malloc_strcat_wordlist_c(&map, mapsep, foo, &mapclue);
+		{
+			for (y = 0; y < ind; y++) 
+			{
+				char *	foo = get_variable(var[y]);
+				malloc_strcat_wordlist(&map, mapsep, foo);
 				new_free(&foo);
 			}
+		}
 
 		if (continue_exception)
 		{
