@@ -56,7 +56,11 @@
  * This is a pointer to a function that may be used as a /BINDing.  
  * The functions themselves live in input.c (and a few other places).
  */
+#if 0
 typedef void (*BindFunction) (unsigned int, char *);
+#else
+typedef BUILT_IN_KEYBINDING((*BindFunction));
+#endif
 
 
 /*
@@ -738,35 +742,37 @@ static void *	timeout_keypress (void *lastp, Timeval pressed)
  */
 static int	do_input_timeouts (void *ignored)
 {
-	Screen *oldscreen = last_input_screen;
+	int	oldscreen = last_input_screen;
 	int 	server = from_server;
-	Screen *screen;
+	int	s;
 
 	/*
 	 * Walk each screen and call timeout_keypress() on it.
 	 * timeout_keypress() checks to see if it has an ambiguous
 	 * keybinding and then resolves it
 	 */
-	for (screen = screen_list; screen; screen = screen->next) 
+	for (s = 0; traverse_all_screens(&s); )
 	{
 		/* Ignore inactive screens */
-		if (!screen->alive) 
+		if (!get_screen_alive(s))
 			continue;
 
 		/* Ignore screens without ambiguous sequences */
-		if (!screen->last_key || screen->last_key == head_keymap)
+		if (!get_screen_last_key(s) || get_screen_last_key(s) == head_keymap)
 			continue;
 
 		/* Set up context and check the sequence */
-		last_input_screen = output_screen = screen;
-		make_window_current_by_refnum(screen->input_window);
+		last_input_screen = s;
+		output_screen = s;
+		make_window_current_by_refnum(get_screen_input_window(s));
 		from_server = get_window_server(0);
 
-		screen->last_key = timeout_keypress(screen->last_key,
-						    screen->last_press);
+		set_screen_last_key(s, timeout_keypress(get_screen_last_key(s),
+							get_screen_last_press(s)));
 	}
 
-	output_screen = last_input_screen = oldscreen;
+	last_input_screen = oldscreen;
+	output_screen = oldscreen;
 	from_server = server;
 	return 0;
 }
@@ -1943,6 +1949,8 @@ char *	bindctl (char *input)
 	    RETURN_STR(retval);
 	} else if (!my_strnicmp(listc, "MATCH", 1)) {
 	    int len;
+	    if (!func || !*func)
+		RETURN_EMPTY;
 	    len = strlen(func);
 	    for (bp = binding_list;bp;bp = bp->next) {
 		if (!my_strnicmp(bp->name, func, len))
